## 1.0.0 (2022-12-18)

### Feat

- Added example cursor pagination
- Added model data to sample project
- Added CursorPageConverter
- Added template tests
- Added pylint configuration
- Using unicode ellipsis
- Added CursorPaginateMixin
- Added paginate_by tests
- Added paginate_cursor_queryset shortcut
- Added implicitly ordered model test
- Added get_order_by function to retrieve queryset ordering
- More order_by tests
- Added condition table
- Sorting NULLs, WIP
- Added tests for invert_order_by
- Added tests for url key encoder / decoder
- Updated .gitignore
- Added pre-commit hook
- Added tests infrastructure
- Implemented cursor navigation
- Added utility functions for cursor navigation
- Export page_range directly to template
- Added .gitignore

### Fix

- Fixed urlsafe pattern matching
- Updated sample project
- Ugly, but it works
- Fixed repeaded line ends

### Refactor

- Migrated to pyproject.toml
- Removed unused code, simplefied
- Cleanup old imports
- Replaced hardcoded string with constant
- Renamed settings to match django get_elided_page_range
- Replaced my ranges calculation with internal

## 0.2 (2017-04-05)

## 0.1 (2017-04-05)
